#
# Conditional build:
%bcond_without	tests		# build without tests
%bcond_with	network_tests	# run tests requiring setup Solr Server on localhost:8983

%define		php_name	php%{?php_suffix}
%define		modname solr
Summary:	Object oriented API to Apache Solr
Summary(fr.UTF-8):	API orientée objet pour Apache Solr
Name:		%{php_name}-pecl-solr
Version:	2.4.0
Release:	3
License:	PHP v3.01
Group:		Development/Languages
Source0:	https://pecl.php.net/get/%{modname}-%{version}.tgz
# Source0-md5:	2c9accf66681a3daaaf371bc07e44902
Patch0:		tests-online.patch
Patch2:		https://github.com/php/pecl-search_engine-solr/commit/744e32915d5989101267ed2c84a407c582dc6f31.patch
# Patch2-md5:	3536677810c1123e4be00a9da56cff5a
URL:		https://pecl.php.net/package/solr
BuildRequires:	%{php_name}-cli
BuildRequires:	%{php_name}-curl
BuildRequires:	%{php_name}-devel >= 4:5.3.0
BuildRequires:	%{php_name}-json
BuildRequires:	curl-devel
BuildRequires:	libxml2-devel >= 1:2.6.16
BuildRequires:	php-packagexml2cl
BuildRequires:	rpmbuild(macros) >= 1.666
%if %{with tests}
BuildRequires:	%{php_name}-pcre
BuildRequires:	%{php_name}-xml
%endif
%{?requires_php_extension}
Requires:	%{php_name}-cli
Requires:	%{php_name}-json
Requires:	%{php_name}-pcre
Requires:	%{php_name}-xml
Provides:	php(solr) = %{version}
Obsoletes:	php-pecl-solr < 1.0.2-6
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Feature-rich library that allows PHP developers to communicate easily
and efficiently with Apache Solr server instances using an
object-oriented API.

It effectively simplifies the process of interacting with Apache Solr
using PHP5 and it already comes with built-in readiness for the latest
features available in Solr 1.4. The extension has features such as
built-in, serializable query string builder objects which effectively
simplifies the manipulation of name-value pair request parameters
across repeated requests. The response from the Solr server is also
automatically parsed into native php objects whose properties can be
accessed as array keys or object properties without any additional
configuration on the client-side. Its advanced HTTP client reuses the
same connection across multiple requests and provides built-in support
for connecting to Solr servers secured behind HTTP Authentication or
HTTP proxy servers. It is also able to connect to SSL-enabled
containers.

Notice: PECL Solr 2.x is not compatible with Apache Solr Server 3.x

%description -l fr.UTF-8
Bibliothèque riche en fonctionnalités qui permet aux développeurs PHP
de communiquer facilement et efficacement avec des instances du
serveur Apache Solr en utilisant une API orientée objet.

Cela simplifie réellement le processus d'interaction avec Apache Solr
en utilisant PHP5 et fournit dores et déjà des facilités pour les
dernières fonctionnalités disponibles dans Solr 1.4. L'extension
possède des fonctionnalités telles qu'un constructeur de requêtes
embarqué et sérialisable qui simplifie réellement la manipulation des
couples de paramètres nom-valeur entre différentes requêtes. La
réponse de Solr est également analysée automatiquement en objets php
natifs dont les propriétés sont accessibles en tant que clés de
tableaux ou en tant que propriétés d'objets sans la moindre
configuration supplémentaire sur le client. Son client HTTP avancé
utilise la même connexion entre différentes requêtes et fournit un
support embarqué pour la connexion aux serveurs Solr protégés par
authentification HTTP ou par un serveur mandataire. Il est également
possible de se connecter à des serveurs via SSL.

%prep
%setup -qc
mv %{modname}-%{version}/* .
%{!?with_network_tests:%patch0 -p1}
%patch2 -p1

cat <<'EOF' > run-tests.sh
#!/bin/sh
export NO_INTERACTION=1 REPORT_EXIT_STATUS=1 MALLOC_CHECK_=2
exec %{__make} test \
	PHP_EXECUTABLE=%{__php} \
	PHP_TEST_SHARED_SYSTEM_EXTENSIONS="json pcre" \
	RUN_TESTS_SETTINGS="-q $*"
EOF
chmod +x run-tests.sh

%build
packagexml2cl package.xml > ChangeLog

# Check version
extver=$(awk -F'"' '/define PHP_SOLR_VERSION / {print $2}' src/php%{php_major_version}/php_solr_version.h)
if test "x${extver}" != "x%{version}"; then
	: Error: Upstream version is ${extver}, expecting %{version}.
	exit 1
fi

phpize
%configure
%{__make}

%{__php} -n -q \
	-d extension_dir=modules \
	-d extension=%{php_extensiondir}/curl.so \
	-d extension=%{php_extensiondir}/json.so \
	-d extension=%{modname}.so \
	-m > modules.log
grep %{modname} modules.log

%if %{with tests}
./run-tests.sh --show-diff
%endif

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{php_sysconfdir}/conf.d,%{php_extensiondir}}
%{__make} install \
	EXTENSION_DIR=%{php_extensiondir} \
	INSTALL_ROOT=$RPM_BUILD_ROOT

cat <<'EOF' > $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d/%{modname}.ini
; Enable Solr extension module
extension=%{modname}.so
EOF

%clean
rm -rf $RPM_BUILD_ROOT

%post
%php_webserver_restart

%postun
if [ "$1" = 0 ]; then
	%php_webserver_restart
fi

%files
%defattr(644,root,root,755)
%doc ChangeLog CREDITS README.SUBMITTING_CONTRIBUTIONS README.MEMORY_ALLOCATION
%doc README.ABOUT_SOLR_EXTENSION TODO LICENSE docs/documentation.php
%config(noreplace) %verify(not md5 mtime size) %{php_sysconfdir}/conf.d/%{modname}.ini
%{php_extensiondir}/%{modname}.so
%changelog
* Tue Dec 04 2018 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/php-pecl-solr.git;a=log;h=auto/th/php-pecl-solr-2.4.0-3

* Tue Aug 07 2018 Elan Ruusamäe <glen@pld-linux.org> d4505b6
- patch to build under php 7.2

* Fri Nov 10 2017 Elan Ruusamäe <glen@pld-linux.org> 53f4a90
- need exts for -m test

* Thu Nov 09 2017 Elan Ruusamäe <glen@pld-linux.org> eb3bdc6
- requires pcre ext; covered by tests

* Thu Nov 09 2017 Elan Ruusamäe <glen@pld-linux.org> 5584ac4
- always test for module load

* Thu Nov 09 2017 Elan Ruusamäe <glen@pld-linux.org> 19ad528
- up to 2.4.0; adds php7 support

* Thu Nov 09 2017 Elan Ruusamäe <glen@pld-linux.org> d7ce20a
- requires php5.3 to build

* Thu May 14 2015 Elan Ruusamäe <glen@delfi.ee> 026132b
- add network_tests bcond

* Thu May 14 2015 Elan Ruusamäe <glen@delfi.ee> de2189f
- run bundled testsuite

* Thu May 14 2015 Elan Ruusamäe <glen@delfi.ee> 7a2204f
- add missing webserver restart

* Thu May 14 2015 Elan Ruusamäe <glen@delfi.ee> a809e4e
- update tests requiring json ext

* Thu May 14 2015 Elan Ruusamäe <glen@delfi.ee> b334e9f
- up to 2.1.0.
Notice: PECL Solr 2.x is not compatible with Apache Solr Server 3.x

* Sat Oct 26 2013 Elan Ruusamäe <glen@delfi.ee> f6a0a36
- fix extension version

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> ba057a0
- BR -xml ext for changelog generation

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> 17a4a15
- obsolete old php name
- release 7 (by relup.sh)

* Wed May 14 2014 Elan Ruusamäe <glen@delfi.ee> 33f3983
- BR cli

* Tue Apr 29 2014 Elan Ruusamäe <glen@delfi.ee> a992aea
- release 5 (by relup.sh)

* Mon Dec 16 2013 Elan Ruusamäe <glen@delfi.ee> b7eea9e
- release 4 (by relup.sh)

* Thu Jul 04 2013 Elan Ruusamäe <glen@delfi.ee> 203c0eb
- requires -cli for tests

* Sun Jun 23 2013 Elan Ruusamäe <glen@delfi.ee> 511528d
- update module load testing

* Fri Jun 21 2013 Elan Ruusamäe <glen@delfi.ee> cbdd8c7
- support building for multiple php versions

